<p align="center">
  <img src="https://raw.githubusercontent.com/jose2kk/pyvenezuela/main/public/logo.png" alt="pyvenezuela"></a>
</p>
<p align="center">
    <em>pyvenezuela, library to query Venezuela's data</em>
</p>
<p align="center">
<a href="https://github.com/jose2kk/pyvenezuela/actions?query=wprlflow:Test+event:push+branch:main" target="_blank">
    <img src="https://github.com/jose2kk/pyvenezuela/workflows/Test/badge.svg" alt="Test">
</a>
</p>

---

**Source Code**: <a href="https://github.com/jose2kk/pyvenezuela" target="_blank">https://github.com/jose2kk/pyvenezuela</a>

---
